#!/usr/bin/env python3
# vim: set shiftwidth=4 softtabstop=4:
"""Tools to help build an image
"""
import logging
import os
import shutil
import sys

from .list_modules import MODULES_LIST_FILE
from .parsing import apply, basic_parser

_logger = logging.getLogger(__name__)

__version__ = "1.0.0"
__date__ = "2020-06-30"
__updated__ = "2020-06-30"


def __parser():
    program_version = __version__
    program_build_date = str(__updated__)
    program_version_message = "%%(prog)s %s (%s)" % (
        program_version,
        program_build_date,
    )
    program_shortdesc = __doc__.split(".")[0]
    program_license = """%s

      Created by Vincent Hatakeyama on %s.
      Copyright 2020 XCG Consulting. All rights reserved.

      Licensed under the MIT License

      Distributed on an "AS IS" basis without warranties
      or conditions of any kind, either express or implied.

    USAGE
    """ % (
        program_shortdesc,
        str(__date__),
    )
    parser = basic_parser(program_license, program_version_message)
    return parser


def main(argv=None):
    """Clean up after a build, callable version that parses arguments
    """
    parser = __parser()
    nmspc = parser.parse_args(argv)
    apply(nmspc)
    # TODO check odoo_scripts before deleting anything
    clean()
    return 0


def clean():
    """Clean up after a build
    """
    if os.path.exists(MODULES_LIST_FILE):
        os.remove(MODULES_LIST_FILE)
    for directory in ("odoo_modules", "static", "odoo_setup"):
        if os.path.exists(directory):
            shutil.rmtree(directory)


if __name__ == "__main__":
    return_code = main(sys.argv[1:])
    if return_code:
        exit(return_code)
